==> flink-1.17.2-src.tgz: flink-1.17.2/flink-runtime-web/web-dashboard/src/app/pages/job/modules/completed-job/cluster-config.guard.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Injectable } from '@angular/core';
import { ActivatedRouteSnapshot, CanActivate, Router, RouterStateSnapshot, UrlTree } from '@angular/router';
import { Observable } from 'rxjs';

import { StatusService } from '@flink-runtime-web/services';

@Injectable({
  providedIn: 'root'
})
export class ClusterConfigGuard implements CanActivate {
  constructor(private statusService: StatusService, private router: Router) {}

  canActivate(
    route: ActivatedRouteSnapshot,
    _: RouterStateSnapshot
  ): Observable<boolean | UrlTree> | Promise<boolean | UrlTree> | boolean | UrlTree {
    const jobId = route.parent!.params.jid;
    const isHistoryServer = this.statusService.configuration.features['web-history'];
    if (!isHistoryServer) {
      this.router.navigate(['/', 'job', 'completed', jobId, 'overview']).then();
      return false;
    }
    return true;
  }
}

==> flink-1.20.2-src.tgz: flink-1.20.2/flink-runtime-web/web-dashboard/src/app/pages/job/modules/completed-job/cluster-config.guard.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Injectable } from '@angular/core';
import { ActivatedRouteSnapshot, Router, RouterStateSnapshot, UrlTree } from '@angular/router';
import { Observable } from 'rxjs';

import { StatusService } from '@flink-runtime-web/services';

@Injectable({
  providedIn: 'root'
})
export class ClusterConfigGuard {
  constructor(private statusService: StatusService, private router: Router) {}

  canActivate(
    route: ActivatedRouteSnapshot,
    _: RouterStateSnapshot
  ): Observable<boolean | UrlTree> | Promise<boolean | UrlTree> | boolean | UrlTree {
    const jobId = route.parent!.params.jid;
    const isHistoryServer = this.statusService.configuration.features['web-history'];
    if (!isHistoryServer) {
      this.router.navigate(['/', 'job', 'completed', jobId, 'overview']).then();
      return false;
    }
    return true;
  }
}
